# Flash responses

## Rendering

::: flyvis.datasets.flashes.RenderedFlashes

## Datasets

::: flyvis.datasets.flashes.Flashes

::: flyvis.datasets.flashes.render_flash

::: flyvis.datasets.dots.Dots

::: flyvis.datasets.dots.CentralImpulses

::: flyvis.datasets.dots.SpatialImpulses

## Analysis

::: flyvis.analysis.flash_responses
